window.Gleam.initSearch([{"doc":"opt_args_with_defs_for_gleam","title":"opt_args_with_defs_for_gleam","content":"# Optional Arguments with Defaults for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/opt_args_with_defs_for_gleam)](https://hex.pm/packages/opt_args_with_defs_for_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/opt_args_with_defs_for_gleam/)\n\n## Notice\n\nOne can be doing quite a bunch of things wrong and get runtime errors.\n\nThis library is more a cursed hack than a good solution and should be mostly\nused to explore how a gleam library public API _would_ look like if gleam\never supported optional arguments with defaults out of the box.\n\n## Installation\n\n```shell\ngleam add opt_args_with_defs_for_gleam\n```\n\n## Example\n\n```gleam\nimport gleam/io\nimport opt_args_with_defs_for_gleam.{O, OB, OF, OI, ON, OS, get_arg, get_args_with}\n\n// Can use string keys as well, but that is more error prone.\ntype OptionalArgumentKeys {\n  SomeNumber\n  SomeFlag\n}\n\nfn fun_with_typed_keys(options: options_keyword_list) -&gt; #(Float, Bool) {\n  let args =\n    [#(SomeNumber, OF(1.0)), #(SomeFlag, OB(True))]\n    |&gt; get_args_with(options)\n\n  let assert OF(some_number) = get_arg(args, SomeNumber)\n  let assert OB(some_flag) = get_arg(args, SomeFlag)\n\n  #(some_number, some_flag)\n}\n\npub fn main() {\n  fun_with_typed_keys([#(SomeNumber, OF(2.0))])\n  |&gt; io.debug() // #(2.0, True)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/opt_args_with_defs_for_gleam&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"opt_args_with_defs_for_gleam","title":"OptionalArgument","content":"pub type OptionalArgument(a) {\n  O(a)\n  OB(Bool)\n  OF(Float)\n  OI(Int)\n  ON(Nil)\n  OS(String)\n}\n\nO(a)\n\n\nOB(Bool)\n\n\nOF(Float)\n\n\nOI(Int)\n\n\nON(Nil)\n\n\nOS(String)\n\n\nSynonyms:\nopt_args_with_defs_for_gleam.OptionalArgument\nopt_args_with_defs_for_gleam OptionalArgument","url":"opt_args_with_defs_for_gleam.html#OptionalArgument"},{"doc":"opt_args_with_defs_for_gleam","title":"get_arg","content":"pub fn get_arg(arguments: a, key: b) -&gt; c\n\nSynonyms:\nopt_args_with_defs_for_gleam.get_arg\nopt_args_with_defs_for_gleam get_arg","url":"opt_args_with_defs_for_gleam.html#get_arg"},{"doc":"opt_args_with_defs_for_gleam","title":"get_args_with","content":"pub fn get_args_with(defaults: a, options: b) -&gt; a\n\nSynonyms:\nopt_args_with_defs_for_gleam.get_args_with\nopt_args_with_defs_for_gleam get_args_with","url":"opt_args_with_defs_for_gleam.html#get_args_with"},{"doc":"opt_args_with_defs_for_gleam","title":"opt_args_with_defs_for_gleam","content":"","url":"opt_args_with_defs_for_gleam.html"},{"doc":"examples/example","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nexamples/example.main\nexamples/example main","url":"examples/example.html#main"},{"doc":"examples/example","title":"examples/example","content":"","url":"examples/example.html"}]);